@@ -28,8 +28,8 @@
 # include <dirent.h>
 #endif
 #if _sys_types \
-    && ! defined (_DI_INC_SYS_TYPES_H) /* xenix */
-# define _DI_INC_SYS_TYPES_H
+    && ! defined (DI_INC_SYS_TYPES_H) /* xenix */
+# define DI_INC_SYS_TYPES_H
 # include <sys/types.h>
 #endif
 #if _sys_param
@@ -61,14 +61,14 @@
 #endif
 
 #if _hdr_mntent \
-  && ! defined (_DI_INC_MNTENT)        /* Linux, kFreeBSD, HP-UX */
-# define _DI_INC_MNTENT 1
+  && ! defined (DI_INC_MNTENT)        /* Linux, kFreeBSD, HP-UX */
+# define DI_INC_MNTENT 1
 # include <mntent.h>            /* hasmntopt(); _PATH_MNTTAB */
 #endif                          /* HP-UX: set/get/endmntent(); hasmntopt() */
 
 #if _sys_mount \
-  && ! defined (_DI_INC_SYS_MOUNT) /* FreeBSD, OpenBSD, NetBSD, HP-UX */
-# define _DI_INC_SYS_MOUNT 1
+  && ! defined (DI_INC_SYS_MOUNT) /* FreeBSD, OpenBSD, NetBSD, HP-UX */
+# define DI_INC_SYS_MOUNT 1
 # include <sys/mount.h>         /* getmntinfo(); struct statfs */
 #endif
 #if _sys_fstypes                /* NetBSD */
@@ -1591,13 +1591,24 @@ di_getDiskEntries (diskInfo, diCount)
           strncpy (handleName, "\\\\.\\", MSDOS_BUFFER_SIZE);
           strncat (handleName, p, MSDOS_BUFFER_SIZE);
           handleName[strlen(handleName)-1] = '\0';
+
+# if _define_IOCTL_STORAGE_CHECK_VERIFY2
+          HANDLE hDevice = CreateFile (handleName,
+              FILE_READ_ATTRIBUTES, FILE_SHARE_READ | FILE_SHARE_WRITE,
+              NULL, OPEN_EXISTING, 0, NULL);
+          bSuccess = DeviceIoControl (hDevice,
+              IOCTL_STORAGE_CHECK_VERIFY2,
+              NULL, 0, NULL, 0, &br, (LPOVERLAPPED) NULL);
+# else
           HANDLE hDevice = CreateFile (handleName,
               GENERIC_READ, FILE_SHARE_READ | FILE_SHARE_WRITE,
               NULL, OPEN_EXISTING, 0, NULL);
-
           bSuccess = DeviceIoControl (hDevice,
               IOCTL_STORAGE_CHECK_VERIFY,
               NULL, 0, NULL, 0, &br, (LPOVERLAPPED) NULL);
+# endif
+          CloseHandle (hDevice);
+
           if (! bSuccess)
           {
             diptr->printFlag = DI_PRNT_BAD;
