@@ -1,9 +1,6 @@
 #!/bin/sh
 #
-# $Id$
-# $Source$
-#
-# Copyright 2001-2012 Brad Lanam, Walnut Creek, California USA
+# Copyright 2001-2018 Brad Lanam, Walnut Creek, California USA
 #
 
 #
@@ -447,7 +444,7 @@ check_shcflags () {
   shcflags="-fPIC $SHCFLAGS"
   if [ "$_MKCONFIG_USING_GCC" != Y ]; then
     case ${_MKCONFIG_SYSTYPE} in
-      CYGWIN*|MSYS*)
+      CYGWIN*|MSYS*|MINGW*)
         shcflags="$SHCFLAGS"
         ;;
       Darwin)
